/*
 * Copyright 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.glance.appwidget

import android.os.Bundle
import androidx.compose.runtime.ProvidableCompositionLocal
import androidx.compose.runtime.staticCompositionLocalOf

/**
 * Option Bundle accessible when generating an App Widget.
 *
 * See [AppWidgetManager#getAppWidgetOptions] for details
 */
public val LocalAppWidgetOptions: ProvidableCompositionLocal<Bundle> =
    staticCompositionLocalOf { error("No default app widget options") }

/**
 * Unique Id for the glance view being generated by the current composition.
 */
public val LocalGlanceId = staticCompositionLocalOf<GlanceId> { error("No default glance id") }
